@@ -6,8 +6,6 @@ Simple static page generator.
 Uses Jinja2 to compile templates.
 """
 
-from __future__ import absolute_import
-
 import inspect
 import logging
 import os
@@ -26,13 +24,7 @@ def _has_argument(func):
     :param func:
         The function to be tested for existence of an argument.
     """
-    if hasattr(inspect, 'signature'):
-        # New way in python 3.3
-        sig = inspect.signature(func)
-        return bool(sig.parameters)
-    else:
-        # Old way
-        return bool(inspect.getargspec(func).args)
+    return bool(inspect.signature(func).parameters)
 
 
 class Site(object):
@@ -62,7 +54,8 @@ class Site(object):
         The encoding of templates to use.
 
     :param logger:
-        A logging.Logger object used to log events.
+        A logging.Logger object used to log events. Defaults to
+        ``logging.getLogger(__name__)``
 
     :param staticpaths:
         .. deprecated:: 0.3.4
@@ -80,9 +73,9 @@ class Site(object):
     def __init__(self,
                  environment,
                  searchpath,
-                 outpath,
-                 encoding,
-                 logger,
+                 outpath=".",
+                 encoding="utf8",
+                 logger=None,
                  contexts=None,
                  rules=None,
                  staticpaths=None,
@@ -92,6 +85,10 @@ class Site(object):
         self.searchpath = searchpath
         self.outpath = outpath
         self.encoding = encoding
+        if logger is None:
+            logger = logging.getLogger(__name__)
+            logger.setLevel(logging.INFO)
+            logger.addHandler(logging.StreamHandler())
         self.logger = logger
         self.contexts = contexts or []
         self.rules = rules or []
@@ -182,11 +179,15 @@ class Site(object):
         """
         # Coerce search to an absolute path if it is not already
         if not os.path.isabs(searchpath):
-            # TODO: Determine if there is a better way to write do this
+            # TODO: Determine if there is a better way to do this
             calling_module = inspect.getmodule(inspect.stack()[-1][0])
-            # Absolute path to project
-            project_path = os.path.realpath(os.path.dirname(
-                calling_module.__file__))
+            if calling_module is None:
+                # Called from the interpreter or similar
+                project_path = os.getcwd()
+            else:
+                # Called from a .py file
+                project_path = os.path.realpath(os.path.dirname(
+                    calling_module.__file__))
             searchpath = os.path.join(project_path, searchpath)
 
         if env_kwargs is None:
@@ -199,14 +200,10 @@ class Site(object):
         environment.filters.update(filters)
         environment.globals.update(env_globals)
 
-        logger = logging.getLogger(__name__)
-        logger.setLevel(logging.INFO)
-        logger.addHandler(logging.StreamHandler())
         return cls(environment,
                    searchpath=searchpath,
                    outpath=outpath,
                    encoding=encoding,
-                   logger=logger,
                    rules=rules,
                    contexts=contexts,
                    staticpaths=staticpaths,
@@ -376,20 +373,14 @@ class Site(object):
         else:
             rule(self, template, **context)
 
-    def render_templates(self, templates, filepath=None):
+    def render_templates(self, templates):
         """Render a collection of :class:`jinja2.Template` objects.
 
         :param templates:
-            A collection of Templates to render.
-
-        :param filepath:
-            Optional. A file or file-like object to dump the complete template
-            stream into. Defaults to to ``os.path.join(self.outpath,
-            template.name)``.
-
+            A collection of :class:`jinja2.Template` objects to render.
         """
         for template in templates:
-            self.render_template(template, filepath)
+            self.render_template(template)
 
     def copy_static(self, files):
         for f in files:
